# asdf-coordinates-schemas
![CI](https://github.com/asdf-format/asdf-coordinates-schemas/workflows/CI/badge.svg)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)

This package provides ASDF schemas for validating coordinates tags.  Users should not
need to install this directly; instead, install an implementation package such
as asdf-astropy, which includes asdf-coordinates-schemas as a dependency.
